Block

Struct Block 

pub struct Block<'c> { /* private fields */ }
A block.

Implementations

Source

impl<'c> Block<'c>

pub fn new(arguments: &[(Type<'c>, Location<'c>)]) -> Self

Creates a block.

pub unsafe fn detach(&self) -> Option<Block<'c>>

Detaches a block from a region and assumes its ownership.

Safety

This function might invalidate existing references to the block if you drop it too early.

pub unsafe fn from_raw(raw: MlirBlock) -> Self

Creates a block from a raw object.

Safety

A raw object must be valid.

pub const fn into_raw(self) -> MlirBlock

Converts a block into a raw object.

pub const fn to_raw(&self) -> MlirBlock

Converts a block into a raw object.